@@ -104,13 +104,7 @@ struct _GstMadClass
   GstElementClass parent_class;
 };
 
-
-GType                   gst_mad_get_type                (void);
-GType                   gst_id3_tag_get_type            (guint type);
-
-GstTagList*             gst_mad_id3_to_tag_list         (const struct id3_tag * tag);
-struct id3_tag *        gst_mad_tag_list_to_id3_tag     (GstTagList *           list);
-
+GType                   gst_mad_get_type (void);
 
 G_END_DECLS
 
