@@ -31,17 +31,17 @@
 
 /* we are unlikely to deal with lengths > 2GB here any time soon, so just
  * return a signed int and use that for error reporting */
-static inline gint
+static gint
 asf_packet_read_varlen_int (guint lentype_flags, guint lentype_bit_offset,
     const guint8 ** p_data, guint * p_size)
 {
-  static const guint lens[4] = { 0, 1, 2, 4 };
+  const guint lens[4] = { 0, 1, 2, 4 };
   guint len, val;
 
   len = lens[(lentype_flags >> lentype_bit_offset) & 0x03];
 
   /* will make caller bail out with a short read if there's not enough data */
-  if (G_UNLIKELY (*p_size < len)) {
+  if (*p_size < len) {
     GST_WARNING ("need %u bytes, but only %u bytes available", len, *p_size);
     return -1;
   }
@@ -91,7 +91,7 @@ asf_payload_find_previous_fragment (AsfPayload * payload, AsfStream * stream)
 {
   AsfPayload *ret;
 
-  if (G_UNLIKELY (stream->payloads->len == 0)) {
+  if (stream->payloads->len == 0) {
     GST_DEBUG ("No previous fragments to merge with for stream %u", stream->id);
     return NULL;
   }
@@ -99,18 +99,10 @@ asf_payload_find_previous_fragment (AsfPayload * payload, AsfStream * stream)
   ret =
       &g_array_index (stream->payloads, AsfPayload, stream->payloads->len - 1);
 
-  if (G_UNLIKELY (ret->mo_size != payload->mo_size ||
-          ret->mo_number != payload->mo_number || ret->mo_offset != 0)) {
-    if (payload->mo_size != 0) {
-      GST_WARNING ("Previous fragment does not match continued fragment");
-      return NULL;
-    } else {
-      /* Warn about this case, but accept it anyway: files in the wild sometimes
-       * have continued packets where the subsequent fragments say that they're
-       * zero-sized. */
-      GST_WARNING ("Previous fragment found, but current fragment has "
-          "zero size, accepting anyway");
-    }
+  if (ret->mo_size != payload->mo_size ||
+      ret->mo_number != payload->mo_number || ret->mo_offset != 0) {
+    GST_WARNING ("Previous fragment does not match continued fragment");
+    return NULL;
   }
 #if 0
   if (this_fragment->mo_offset + this_payload_len > first_fragment->mo_size) {
@@ -132,15 +124,15 @@ gst_asf_payload_queue_for_stream (GstASFDemux * demux, AsfPayload * payload,
   GST_DEBUG_OBJECT (demux, "Got payload for stream %d ts:%" GST_TIME_FORMAT,
       stream->id, GST_TIME_ARGS (payload->ts));
   /* remember the first timestamp in the stream */
-  if (G_UNLIKELY (!GST_CLOCK_TIME_IS_VALID (demux->first_ts) &&
-          GST_CLOCK_TIME_IS_VALID (payload->ts))) {
+  if (!GST_CLOCK_TIME_IS_VALID (demux->first_ts) &&
+      GST_CLOCK_TIME_IS_VALID (payload->ts)) {
     GST_DEBUG_OBJECT (demux, "first ts: %" GST_TIME_FORMAT,
         GST_TIME_ARGS (payload->ts));
     demux->first_ts = payload->ts;
   }
 
   /* make timestamps start from 0 */
-  if (G_LIKELY (demux->first_ts < payload->ts))
+  if (demux->first_ts < payload->ts)
     payload->ts -= demux->first_ts;
   else
     payload->ts = 0;
@@ -153,7 +145,7 @@ gst_asf_payload_queue_for_stream (GstASFDemux * demux, AsfPayload * payload,
     idx_last = stream->payloads->len - 1;
     prev = &g_array_index (stream->payloads, AsfPayload, idx_last);
 
-    if (G_UNLIKELY (gst_asf_payload_is_complete (prev)))
+    if (gst_asf_payload_is_complete (prev))
       break;
 
     GST_DEBUG_OBJECT (demux, "Dropping incomplete fragmented media object "
@@ -172,8 +164,8 @@ gst_asf_payload_queue_for_stream (GstASFDemux * demux, AsfPayload * payload,
    * absolutely necessary after a seek (we don't push out payloads that are
    * before the segment start until we have at least one that falls within the
    * segment) */
-  if (G_UNLIKELY (GST_CLOCK_TIME_IS_VALID (payload->ts) &&
-          payload->ts < demux->segment.start && payload->keyframe)) {
+  if (GST_CLOCK_TIME_IS_VALID (payload->ts) &&
+      payload->ts < demux->segment.start && payload->keyframe) {
     GST_DEBUG_OBJECT (demux, "Queueing keyframe before segment start, removing"
         " %u previously-queued payloads, which would be out of segment too and"
         " hence don't have to be decoded", stream->payloads->len);
@@ -192,8 +184,8 @@ gst_asf_payload_queue_for_stream (GstASFDemux * demux, AsfPayload * payload,
   }
 
   /* remember the first queued timestamp for the segment */
-  if (G_UNLIKELY (!GST_CLOCK_TIME_IS_VALID (demux->segment_ts) &&
-          GST_CLOCK_TIME_IS_VALID (payload->ts))) {
+  if (!GST_CLOCK_TIME_IS_VALID (demux->segment_ts) &&
+      GST_CLOCK_TIME_IS_VALID (payload->ts)) {
     GST_DEBUG_OBJECT (demux, "segment ts: %" GST_TIME_FORMAT,
         GST_TIME_ARGS (payload->ts));
     demux->segment_ts = payload->ts;
@@ -219,23 +211,21 @@ asf_payload_parse_replicated_data_extensions (AsfStream * stream,
 
   off = 8;
   for (ext = stream->ext_props.payload_extensions; ext->len > 0; ++ext) {
-    if (G_UNLIKELY (off + ext->len > payload->rep_data_len)) {
+    if (off + ext->len > payload->rep_data_len) {
       GST_WARNING ("not enough replicated data for defined extensions");
       return;
     }
     switch (ext->id) {
       case ASF_PAYLOAD_EXTENSION_DURATION:
-        if (G_LIKELY (ext->len == 2)) {
-          guint16 tdur = GST_READ_UINT16_LE (payload->rep_data + off);
-          /* packet durations of 1ms are mostly invalid */
-          if (tdur != 1)
-            payload->duration = tdur * GST_MSECOND;
+        if (ext->len == 2) {
+          payload->duration =
+              GST_READ_UINT16_LE (payload->rep_data + off) * GST_MSECOND;
         } else {
           GST_WARNING ("unexpected DURATION extensions len %u", ext->len);
         }
         break;
       case ASF_PAYLOAD_EXTENSION_SYSTEM_CONTENT:
-        if (G_LIKELY (ext->len == 1)) {
+        if (ext->len == 1) {
           guint8 data = payload->rep_data[off];
 
           payload->interlaced = data & 0x1;
@@ -248,7 +238,7 @@ asf_payload_parse_replicated_data_extensions (AsfStream * stream,
         }
         break;
       case ASF_PAYLOAD_EXTENSION_SYSTEM_PIXEL_ASPECT_RATIO:
-        if (G_LIKELY (ext->len == 2)) {
+        if (ext->len == 2) {
           payload->par_x = payload->rep_data[off];
           payload->par_y = payload->rep_data[off + 1];
           GST_DEBUG ("PAR %d / %d", payload->par_x, payload->par_y);
@@ -275,7 +265,7 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
   guint payload_len;
   guint stream_num;
 
-  if (G_UNLIKELY (*p_size < 1)) {
+  if (*p_size < 1) {
     GST_WARNING_OBJECT (demux, "Short packet!");
     return FALSE;
   }
@@ -307,7 +297,7 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
   GST_LOG_OBJECT (demux, "keyframe   : %s", (payload.keyframe) ? "yes" : "no");
   GST_LOG_OBJECT (demux, "compressed : %s", (is_compressed) ? "yes" : "no");
 
-  if (G_UNLIKELY (*p_size < payload.rep_data_len)) {
+  if (*p_size < payload.rep_data_len) {
     GST_WARNING_OBJECT (demux, "Short packet! rep_data_len=%u, size=%u",
         payload.rep_data_len, *p_size);
     return FALSE;
@@ -319,13 +309,13 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
   *p_data += payload.rep_data_len;
   *p_size -= payload.rep_data_len;
 
-  if (G_UNLIKELY (*p_size == 0)) {
+  if (*p_size == 0) {
     GST_WARNING_OBJECT (demux, "payload without data!?");
     return FALSE;
   }
 
   /* we use -1 as lentype for a single payload that's the size of the packet */
-  if (G_UNLIKELY ((lentype >= 0 && lentype <= 3))) {
+  if (lentype >= 0 && lentype <= 3) {
     payload_len = asf_packet_read_varlen_int (lentype, 0, p_data, p_size);
     if (*p_size < payload_len) {
       GST_WARNING_OBJECT (demux, "Short packet! payload_len=%u, size=%u",
@@ -340,29 +330,21 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
 
   stream = gst_asf_demux_get_stream (demux, stream_num);
 
-  if (G_UNLIKELY (stream == NULL)) {
+  if (stream == NULL) {
     GST_WARNING_OBJECT (demux, "Payload for unknown stream %u, skipping",
         stream_num);
-    if (*p_size < payload_len) {
-      *p_data += *p_size;
-      *p_size = 0;
-    } else {
-      *p_data += payload_len;
-      *p_size -= payload_len;
-    }
+    *p_data += payload_len;
+    *p_size -= payload_len;
     return TRUE;
   }
 
-  if (G_UNLIKELY (!is_compressed)) {
+  if (!is_compressed) {
     GST_LOG_OBJECT (demux, "replicated data length: %u", payload.rep_data_len);
 
     if (payload.rep_data_len >= 8) {
       payload.mo_size = GST_READ_UINT32_LE (payload.rep_data);
       payload.ts = GST_READ_UINT32_LE (payload.rep_data + 4) * GST_MSECOND;
-      if (G_UNLIKELY (payload.ts < demux->preroll))
-        payload.ts = 0;
-      else
-        payload.ts -= demux->preroll;
+      payload.ts -= demux->preroll;
       asf_payload_parse_replicated_data_extensions (stream, &payload);
 
       GST_LOG_OBJECT (demux, "media object size   : %u", payload.mo_size);
@@ -381,8 +363,7 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
 
     GST_LOG_OBJECT (demux, "payload length: %u", payload_len);
 
-    if ((stream = gst_asf_demux_get_stream (demux, stream_num))
-        && payload_len) {
+    if ((stream = gst_asf_demux_get_stream (demux, stream_num))) {
       payload.buf = asf_packet_create_payload_buffer (packet, p_data, p_size,
           payload_len);
 
@@ -418,11 +399,7 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
     *p_data += payload_len;
     *p_size -= payload_len;
 
-    ts = payload.mo_offset * GST_MSECOND;
-    if (G_UNLIKELY (ts < demux->preroll))
-      ts = 0;
-    else
-      ts -= demux->preroll;
+    ts = payload.mo_offset * GST_MSECOND - demux->preroll;
     ts_delta = payload.rep_data[0] * GST_MSECOND;
 
     for (num = 0; payload_len > 0; ++num) {
@@ -436,20 +413,17 @@ gst_asf_demux_parse_payload (GstASFDemux * demux, AsfPacket * packet,
       ++payload_data;
       --payload_len;
 
-      if (G_UNLIKELY (payload_len < sub_payload_len)) {
+      if (payload_len < sub_payload_len) {
         GST_WARNING_OBJECT (demux, "Short payload! %u bytes left", payload_len);
         return FALSE;
       }
 
-      if (G_LIKELY (sub_payload_len > 0)) {
+      if (sub_payload_len > 0) {
         payload.buf = asf_packet_create_payload_buffer (packet,
             &payload_data, &payload_len, sub_payload_len);
 
         payload.ts = ts;
-        if (G_LIKELY (ts_delta))
-          payload.duration = ts_delta;
-        else
-          payload.duration = GST_CLOCK_TIME_NONE;
+        payload.duration = ts_delta;
 
         gst_asf_payload_queue_for_stream (demux, &payload, stream);
       }
@@ -473,10 +447,9 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
 
   data = GST_BUFFER_DATA (buf);
   size = GST_BUFFER_SIZE (buf);
-  GST_LOG_OBJECT (demux, "Buffer size: %u", size);
 
   /* need at least two payload flag bytes, send time, and duration */
-  if (G_UNLIKELY (size < 2 + 4 + 2))
+  if (size < 2 + 4 + 2)
     goto short_packet;
 
   packet.buf = buf;
@@ -495,7 +468,7 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
           ec_len_type);
       ec_len = 2;
     }
-    GST_LOG_OBJECT (demux, "packet has error correction (%u bytes)", ec_len);
+    GST_LOG ("packet has error correction (%u bytes)", ec_len);
 
     /* still need at least two payload flag bytes, send time, and duration */
     if (size <= (1 + ec_len) + 2 + 4 + 2)
@@ -520,7 +493,7 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
 
   packet.padding = asf_packet_read_varlen_int (flags1, 3, &data, &size);
 
-  if (G_UNLIKELY (size < 6))
+  if (size < 6)
     goto short_packet;
 
   packet.send_time = GST_READ_UINT32_LE (data) * GST_MSECOND;
@@ -529,7 +502,6 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
   data += 4 + 2;
   size -= 4 + 2;
 
-  GST_LOG_OBJECT (demux, "flags            : 0x%x", flags1);
   GST_LOG_OBJECT (demux, "multiple payloads: %u", has_multiple_payloads);
   GST_LOG_OBJECT (demux, "packet length    : %u", packet.length);
   GST_LOG_OBJECT (demux, "sequence         : %u", packet.sequence);
@@ -539,30 +511,22 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
   GST_LOG_OBJECT (demux, "duration         : %" GST_TIME_FORMAT,
       GST_TIME_ARGS (packet.duration));
 
-  if (G_UNLIKELY (packet.padding == (guint) - 1 || size < packet.padding))
+  if (packet.padding == (guint) - 1 || size < packet.padding)
     goto short_packet;
 
   size -= packet.padding;
 
   /* adjust available size for parsing if there's less actual packet data for
    * parsing than there is data in bytes (for sample see bug 431318) */
-  if (G_UNLIKELY (packet.length != 0 && packet.padding == 0
-          && packet.length < demux->packet_size)) {
-    GST_LOG_OBJECT (demux, "shortened packet with implicit padding, "
-        "adjusting available data size");
-    if (size < demux->packet_size - packet.length) {
-      /* the buffer is smaller than the implicit padding */
-      goto short_packet;
-    } else {
-      /* subtract the implicit padding */
-      size -= (demux->packet_size - packet.length);
-    }
+  if (packet.length != 0 && packet.length < demux->packet_size) {
+    GST_LOG_OBJECT (demux, "shortened packet, adjusting available data size");
+    size -= (demux->packet_size - packet.length);
   }
 
   if (has_multiple_payloads) {
     guint i, num, lentype;
 
-    if (G_UNLIKELY (size < 1))
+    if (size < 1)
       goto short_packet;
 
     num = (GST_READ_UINT8 (data) & 0x3F) >> 0;
@@ -574,12 +538,11 @@ gst_asf_demux_parse_packet (GstASFDemux * demux, GstBuffer * buf)
     GST_LOG_OBJECT (demux, "num payloads     : %u", num);
 
     for (i = 0; i < num; ++i) {
-      GST_LOG_OBJECT (demux, "Parsing payload %u/%u, size left: %u", i + 1, num,
-          size);
+      GST_LOG_OBJECT (demux, "Parsing payload %u/%u", i + 1, num);
 
       ret = gst_asf_demux_parse_payload (demux, &packet, lentype, &data, &size);
 
-      if (G_UNLIKELY (!ret)) {
+      if (!ret) {
         GST_WARNING_OBJECT (demux, "Failed to parse payload %u/%u", i + 1, num);
         break;
       }
