@@ -41,16 +41,19 @@
 #include "config.h"
 #endif
 
-/* FIXME 0.11: suppress warnings for deprecated API such as GStaticRecMutex
- * with newer GLib versions (>= 2.31.0) */
-#define GLIB_DISABLE_DEPRECATION_WARNINGS
-
 #include "rademux.h"
 #include "rmdemux.h"
 #include "rmutils.h"
 
 #include <string.h>
 
+static GstElementDetails real_audio_demux_details = {
+  "RealAudio Demuxer",
+  "Codec/Demuxer",
+  "Demultiplex a RealAudio file",
+  "Tim-Philipp Müller <tim centricular net>"
+};
+
 static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
@@ -86,13 +89,11 @@ gst_real_audio_demux_base_init (gpointer klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &sink_template);
-  gst_element_class_add_static_pad_template (element_class, &src_template);
-  gst_element_class_set_details_simple (element_class, "RealAudio Demuxer",
-      "Codec/Demuxer",
-      "Demultiplex a RealAudio file",
-      "Tim-Philipp Müller <tim centricular net>");
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&src_template));
+  gst_element_class_set_details (element_class, &real_audio_demux_details);
 
   GST_DEBUG_CATEGORY_INIT (real_audio_demux_debug, "rademux",
       0, "Demuxer for RealAudio streams");
@@ -304,8 +305,8 @@ gst_real_audio_demux_get_data_offset_from_header (GstRealAudioDemux * demux)
 static GstFlowReturn
 gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
 {
+  const gchar *codec_name = NULL;
   const guint8 *data;
-  gchar *codec_name = NULL;
   GstCaps *caps = NULL;
   guint avail;
 
@@ -381,6 +382,7 @@ gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
     case GST_RM_AUD_14_4:
       caps = gst_caps_new_simple ("audio/x-pn-realaudio", "raversion",
           G_TYPE_INT, 1, NULL);
+      codec_name = "Real Audio 14.4kbps";
       demux->byterate_num = 1000;
       demux->byterate_denom = 1;
       break;
@@ -389,9 +391,11 @@ gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
       /* FIXME: needs descrambling */
       caps = gst_caps_new_simple ("audio/x-pn-realaudio", "raversion",
           G_TYPE_INT, 2, NULL);
+      codec_name = "Real Audio 28.8kbps";
       break;
 
     case GST_RM_AUD_DNET:
+      codec_name = "AC-3 audio";
       caps = gst_caps_new_simple ("audio/x-ac3", "rate", G_TYPE_INT,
           demux->sample_rate, NULL);
       if (demux->packet_size == 0 || demux->sample_rate == 0)
@@ -402,6 +406,7 @@ gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
 
       /* Sipro/ACELP.NET Voice Codec (MIME unknown) */
     case GST_RM_AUD_SIPR:
+      codec_name = "Sipro Voice";
       caps = gst_caps_new_simple ("audio/x-sipro", NULL);
       break;
 
@@ -426,7 +431,6 @@ gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
   demux->srcpad = gst_pad_new_from_static_template (&src_template, "src");
   gst_pad_use_fixed_caps (demux->srcpad);
   gst_pad_set_caps (demux->srcpad, caps);
-  codec_name = gst_pb_utils_get_codec_description (caps);
   gst_caps_unref (caps);
   gst_pad_set_event_function (demux->srcpad,
       GST_DEBUG_FUNCPTR (gst_real_audio_demux_src_event));
@@ -462,7 +466,6 @@ gst_real_audio_demux_parse_header (GstRealAudioDemux * demux)
 
     gst_tag_list_add (demux->pending_tags, GST_TAG_MERGE_REPLACE,
         GST_TAG_AUDIO_CODEC, codec_name, NULL);
-    g_free (codec_name);
   }
 
   gst_adapter_flush (demux->adapter, demux->data_offset - 6);
@@ -509,8 +512,13 @@ gst_real_audio_demux_parse_data (GstRealAudioDemux * demux)
     const guint8 *data;
     GstBuffer *buf = NULL;
 
-    buf = gst_buffer_new_and_alloc (unit_size);
-    gst_buffer_set_caps (buf, GST_PAD_CAPS (demux->srcpad));
+    ret = gst_pad_alloc_buffer_and_set_caps (demux->srcpad,
+        GST_BUFFER_OFFSET_NONE, unit_size, GST_PAD_CAPS (demux->srcpad), &buf);
+
+    if (ret != GST_FLOW_OK) {
+      GST_DEBUG_OBJECT (demux, "pad_alloc flow: %s", gst_flow_get_name (ret));
+      break;
+    }
 
     data = gst_adapter_peek (demux->adapter, unit_size);
     memcpy (GST_BUFFER_DATA (buf), data, unit_size);
@@ -572,7 +580,7 @@ gst_real_audio_demux_handle_buffer (GstRealAudioDemux * demux, GstBuffer * buf)
       break;
     }
     default:
-      g_return_val_if_reached (GST_FLOW_ERROR);
+      g_assert_not_reached ();
   }
 
   return ret;
@@ -614,7 +622,7 @@ gst_real_audio_demux_loop (GstRealAudioDemux * demux)
       }
       break;
     default:
-      g_return_if_reached ();
+      g_assert_not_reached ();
   }
 
   /* now get the data */
