@@ -56,13 +56,16 @@
 #include "rdtmanager.h"
 #include "rdtjitterbuffer.h"
 
-#include <gst/glib-compat-private.h>
-
-#include <stdio.h>
-
 GST_DEBUG_CATEGORY_STATIC (rdtmanager_debug);
 #define GST_CAT_DEFAULT (rdtmanager_debug)
 
+/* elementfactory information */
+static const GstElementDetails rdtmanager_details =
+GST_ELEMENT_DETAILS ("RTP Decoder",
+    "Codec/Parser/Network",
+    "Accepts raw RTP and RTCP packets and sends them forward",
+    "Wim Taymans <wim@fluendo.com>");
+
 /* GstRDTManager signals and args */
 enum
 {
@@ -327,26 +330,23 @@ gst_rdt_manager_base_init (gpointer klass)
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
   /* sink pads */
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rdt_manager_recv_rtp_sink_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rdt_manager_recv_rtcp_sink_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtp_sink_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtcp_sink_template));
   /* src pads */
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rdt_manager_recv_rtp_src_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rdt_manager_rtcp_src_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rdt_manager_recv_rtp_src_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rdt_manager_rtcp_src_template));
 
-  gst_element_class_set_details_simple (element_class, "RTP Decoder",
-      "Codec/Parser/Network",
-      "Accepts raw RTP and RTCP packets and sends them forward",
-      "Wim Taymans <wim@fluendo.com>");
+  gst_element_class_set_details (element_class, &rdtmanager_details);
 }
 
 /* BOXED:UINT,UINT */
 #define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
 
-static void
+void
 gst_rdt_manager_marshal_BOXED__UINT_UINT (GClosure * closure,
     GValue * return_value,
     guint n_param_values,
@@ -371,8 +371,8 @@ gst_rdt_manager_marshal_BOXED__UINT_UINT (GClosure * closure,
     data2 = closure->data;
   }
   callback =
-      (GMarshalFunc_BOXED__UINT_UINT) (marshal_data ? marshal_data :
-      cc->callback);
+      (GMarshalFunc_BOXED__UINT_UINT) (marshal_data ? marshal_data : cc->
+      callback);
 
   v_return = callback (data1,
       g_marshal_value_peek_uint (param_values + 1),
@@ -381,7 +381,7 @@ gst_rdt_manager_marshal_BOXED__UINT_UINT (GClosure * closure,
   g_value_take_boxed (return_value, v_return);
 }
 
-static void
+void
 gst_rdt_manager_marshal_VOID__UINT_UINT (GClosure * closure,
     GValue * return_value,
     guint n_param_values,
@@ -404,8 +404,8 @@ gst_rdt_manager_marshal_VOID__UINT_UINT (GClosure * closure,
     data2 = closure->data;
   }
   callback =
-      (GMarshalFunc_VOID__UINT_UINT) (marshal_data ? marshal_data :
-      cc->callback);
+      (GMarshalFunc_VOID__UINT_UINT) (marshal_data ? marshal_data : cc->
+      callback);
 
   callback (data1,
       g_marshal_value_peek_uint (param_values + 1),
@@ -430,7 +430,7 @@ gst_rdt_manager_class_init (GstRDTManagerClass * g_class)
   g_object_class_install_property (gobject_class, PROP_LATENCY,
       g_param_spec_uint ("latency", "Buffer latency in ms",
           "Amount of ms to buffer", 0, G_MAXUINT, DEFAULT_LATENCY_MS,
-          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          G_PARAM_READWRITE));
 
   /**
    * GstRDTManager::request-pt-map:
@@ -874,8 +874,9 @@ do_eos:
   }
 pause:
   {
-    GST_DEBUG_OBJECT (rdtmanager, "pausing task, reason %s",
-        gst_flow_get_name (result));
+    const gchar *reason = gst_flow_get_name (result);
+
+    GST_DEBUG_OBJECT (rdtmanager, "pausing task, reason %s", reason);
 
     JBUF_LOCK (session);
     /* store result */
